Rohde & Schwarz OSP Opens Switch Platform RsOsp instrument driver Version 1.0.4.58

Check out the module documentation on https://RsOsp.readthedocs.io/

Release Notes:

Latest release notes summary: Added documentation on ReadTheDocs

Version 1.0.4.58

- Added documentation on ReadTheDocs

Version 1.0.4.57

- Fixed formatting of string in methods with list of paths as inputs

Version 1.0.3.55

- Changed responses for methods with List[string] return values: If the instrument returns exactly one empty string, the methods return empty List []

Version 1.0.2.54

- Fixed parsing of the instrument errors when an error message contains two double quotes

Version 1.0.0.50

- First released version